/* $Id: xutils.h,v 1.4 2008/04/30 20:52:42 hacki Exp $ */

/*
 * Copyright (c) 2005, 2006 Marcus Glocker <marcus@nazgul.ch>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

/*
 * prototypes
 */
int		flush_expose(Window);
void		copyXPMArea(int, int, int, int, int, int);
void		copyXBMArea(int, int, int, int, int, int);
void		RedrawWindow(void);
void		initXwindow(char *);
void		openXwindow(int, char **, char **, unsigned char *, int, int);
unsigned long	getColor(char *, float, int *, int *, int *);
unsigned long	getBlendedColor(char *, float, int, int, int);

/*
 * global variables
 */
Display	*display;
Window	Root;
Window 	win, iconwin;
int	screen;
int	DisplayDepth;

/*
 * typedefs
 */
typedef struct {
	Pixmap		pixmap;
	Pixmap		mask;
	XpmAttributes	attributes;
} XpmIcon;
